@@ -30,7 +30,6 @@ import matplotlib.pyplot as plt
 # from mpl_toolkits.axes_grid1.axes_divider import make_axes_locatable
 from mpl_toolkits.mplot3d import Axes3D
 import numpy as np
-import importlib_resources
 import pkg_resources
 
 
@@ -53,15 +52,13 @@ class Lidar():
         
     def region(self):
         self.output_slider_variable = widgets.Text()
-#         stream = pkg_resources.resource_stream(__name__, 'data/filename.txt')
-        my_resources = importlib_resources.files("package")
-        data = (my_resources / "data" / "filename.txt").read_bytes()
+        stream = pkg_resources.resource_stream(__name__, 'data/filename.txt')
        
         # Define function to bind value of the input to the output variable 
         def f(x):
             self.output_slider_variable.value = str(x)
 
-        dropdown = interact(f, x=read_text(data))
+        dropdown = interact(f, x=read_text(stream.read_bytes()))
         return self.output_slider_variable
 
     def ept_json(self):
